function result = cholIdentification(varmodel, draws, nirf, percentiles, normalizeShocks)
% PURPOSE: Compute cholesky restrictions for structural VAR
% identification
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Input:
%
% varmodel = Object of estimated VAR
%
% draws = Number of bootstraps (to simulate confidence bands)
%
% nirf = Impulse-response horizon
%
% normalizeShocks = Logical indicating whether the structural shocks should
%                   be normalized to 1 unit on impact
%
%
% Output:
%
% mse = Mean squared error
%
% irf = Impulse response functions
%
% vdc = Forecast error variance decompositions
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

alphac = varmodel.alphac;
betac = varmodel.betac;
resid = varmodel.resid;
nlag = varmodel.nlag;
Sigma2 = varmodel.Sigma2;
nvary = varmodel.nvary;

% bootstrapped parameter values
[alphab,betab,Sigma2b]=varSimulation(alphac,betac,resid,nlag,draws);

% Compute MSE, IRFs and VDC using Cholesky identification
% Point estimate mse
mse=getMse(betac,Sigma2,nirf);

% get comp form of simulated parameters
[betacb,alphacb]=varGetCompForm(betab,alphab,nlag,nvary);

% Cholesky identification
irf=varImpulseResponsFast(betac,nvary,nlag,nirf,chol(Sigma2,'lower'));


vdc=getVdcFromIrf(irf);

%...get for different draws (i.e., simulate)
[irfb,vdcb]=deal(nan(nvary,nvary,nirf,draws));
for d=1:draws
    irfb(:,:,:,d)=varImpulseResponsFast(betacb(:,:,d),nvary,nlag,nirf,chol(Sigma2b(:,:,d),'lower'));
    vdcb(:,:,:,d)=getVdcFromIrf(irfb(:,:,:,d));
   
    % Normalize shocks
    if normalizeShocks == 1
        for i = 1:size(irfb, 2)
            normConstant = irfb(i, i, 1, d);
            irfb(:, i, :, d) = irfb(:, i, :, d) ./ normConstant;
        end
    end
end;


% Normalize shocks
if normalizeShocks == 1
    for i = 1:size(irf, 2)
        normConstant = irf(i, i, 1);
        irf(:, i, :) = irf(:, i, :) ./ normConstant;
    end
end



% Get percentiles
irfb = getPercentiles(irfb, percentiles);

result.mse=mse;
result.irf=irf;
result.vdc=vdc;
result.irfb=irfb;
result.vdcb=vdcb;