function result = estimateVAR(Y, nlag, deterministic, exog)
% PURPOSE: Estimate VAR-model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Input:
%
%   Y = Matrix with endogenous variables, (t x n) where t is number of obs, 
%       and n is number of variables.    
%
%   nlag = Number of lags to include in the VAR
%
%   deterministic = Specifies whether the VAR should be estimated with
%                   a constant and/or a linear time trend.
%                   deterministic = 0: do not include constant or trend
%                   deterministic = 1: include constant
%                   deterministic = 2: include constant and linear trend
%
%   exog = Matrix with exogenous variables, (t x m) where t is number of obs, 
%          and m is number of variables.
%
% Output:
%
%   results = A struct with the results from the estimation
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[T, nvary] = size(Y);

if nargin < 4
    exog = [];
end

if deterministic == 1
    exog = [ones(T, 1), exog];
elseif deterministic == 2
    exog = [ones(T, 1), (1:T)', exog];
end

nexog = size(exog, 2);

X = [exog, latMlag(Y, nlag)];
     
y = Y(1 + nlag:end, :);
x = X(1 + nlag:end, :);

[nobs, nvary] = size(y);
nvarx = size(x, 2);

% OLS
coeff = ((x' * x) \ (x' * y))';
if nexog == 0
    alpha = [];
    beta = coeff;
else
    alpha = coeff(:, 1:nexog);
    beta = coeff(:, nexog + 1:end);   
end

yhat = (coeff * x')';
resid = y - yhat;

% ML estimate of covaraince of residuals
Sigma2 = (resid' * resid) / nobs;

[betac, alphac] = varGetCompForm(beta, alpha, nlag, nvary);

result.y = y;
result.x = x;
result.alpha = alpha;
result.beta = beta;
result.yhat = yhat;
result.resid = resid;
result.betac = betac;
result.alphac = alphac;
result.nlag = nlag;
result.Sigma2 = Sigma2;
result.nvary = nvary;